@@ -13,8 +13,10 @@ class Evopedia : public QObject
 {
     Q_OBJECT
 public:
-    Evopedia(QObject *parent=0);
+    explicit Evopedia(QObject *parent=0);
+
     StorageBackend *getBackend(const QString language) const;
+    bool hasLanguage(const QString language) const { return storages.contains(language); }
     const QList<StorageBackend *> getBackends() const;
     StorageBackend *getRandomBackend() const;
 
@@ -23,12 +25,16 @@ public:
 
     QUrl getArticleUrl(const Title &t) const;
 
+    void setNetworkUse(int use);
+    bool networkConnectionAllowed();
+
 signals:
     void backendsChanged(const QList<StorageBackend *> backends);
 
 private:
     QHash<QString,StorageBackend *> storages;
     EvopediaWebServer *webServer;
+    int networkUse;
 };
 
 #endif // EVOPEDIA_H
