@@ -11,8 +11,8 @@ class FlickableMap : public QWidget, public Flickable
     Q_OBJECT
 public:
     explicit FlickableMap(QWidget *parent = 0);
-    void setEvopedia(Evopedia *evopedia);
     void setPosition(qreal lat, qreal lng, int zoom=-1);
+    void getPosition(qreal &lat, qreal &lng, int &zoom);
 
 public slots:
     void zoomIn();
