@@ -13,16 +13,17 @@ class MapWindow : public QMainWindow
 {
     Q_OBJECT
 public:
-    explicit MapWindow(Evopedia *evopedia, QWidget *parent = 0);
+    explicit MapWindow(QWidget *parent = 0);
     ~MapWindow();
 
     /* TODO1 request current GPS position */
     void setPosition(qreal lat, qreal lng, int zoom=-1);
+    void getPosition(qreal &lat, qreal &lng, int &zoom);
 
 private slots:
     void delayedInit() {
 #if defined(Q_OS_SYMBIAN)
-        qt_SetDefaultIap();
+//        qt_SetDefaultIap();
 #endif
 #if defined(Q_WS_MAEMO_5)
         grabZoomKeys(true);
